@@ -15,15 +15,10 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Tests for AHI compositors.
-"""
+"""Tests for AHI compositors."""
 
 import sys
-
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 
 class TestAHIComposites(unittest.TestCase):
@@ -68,12 +63,3 @@ class TestAHIComposites(unittest.TestCase):
                          'toa_bidirectional_reflectance')
         data = res.compute()
         np.testing.assert_allclose(data, 0.2575)
-
-
-def suite():
-    """The test suite for test_ahi.
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestAHIComposites))
-    return mysuite
