@@ -18,11 +18,7 @@
 """The abi_l1b reader tests package."""
 
 import unittest
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
+from unittest import mock
 import warnings
 import numpy as np
 import dask.array as da
@@ -39,6 +35,7 @@ class TestAHIHSDNavigation(unittest.TestCase):
     @mock.patch('satpy.readers.ahi_hsd.np.fromfile')
     def test_region(self, fromfile, np2str):
         """Test region navigation."""
+        from pyresample.utils import proj4_radius_parameters
         np2str.side_effect = lambda x: x
         m = mock.mock_open()
         with mock.patch('satpy.readers.ahi_hsd.open', m, create=True):
@@ -71,8 +68,9 @@ class TestAHIHSDNavigation(unittest.TestCase):
 
             area_def = fh.get_area_def(None)
             proj_dict = area_def.proj_dict
-            self.assertEqual(proj_dict['a'], 6378137.0)
-            self.assertEqual(proj_dict['b'], 6356752.3)
+            a, b = proj4_radius_parameters(proj_dict)
+            self.assertEqual(a, 6378137.0)
+            self.assertEqual(b, 6356752.3)
             self.assertEqual(proj_dict['h'], 35785863.0)
             self.assertEqual(proj_dict['lon_0'], 140.7)
             self.assertEqual(proj_dict['proj'], 'geos')
@@ -84,6 +82,7 @@ class TestAHIHSDNavigation(unittest.TestCase):
     @mock.patch('satpy.readers.ahi_hsd.np.fromfile')
     def test_segment(self, fromfile, np2str):
         """Test segment navigation."""
+        from pyresample.utils import proj4_radius_parameters
         np2str.side_effect = lambda x: x
         m = mock.mock_open()
         with mock.patch('satpy.readers.ahi_hsd.open', m, create=True):
@@ -116,8 +115,9 @@ class TestAHIHSDNavigation(unittest.TestCase):
 
             area_def = fh.get_area_def(None)
             proj_dict = area_def.proj_dict
-            self.assertEqual(proj_dict['a'], 6378137.0)
-            self.assertEqual(proj_dict['b'], 6356752.3)
+            a, b = proj4_radius_parameters(proj_dict)
+            self.assertEqual(a, 6378137.0)
+            self.assertEqual(b, 6356752.3)
             self.assertEqual(proj_dict['h'], 35785863.0)
             self.assertEqual(proj_dict['lon_0'], 140.7)
             self.assertEqual(proj_dict['proj'], 'geos')
@@ -355,16 +355,3 @@ class TestAHIHSDFileHandler(unittest.TestCase):
             {'blocklength': 0}]
         with mock.patch('numpy.fromfile', side_effect=nhdr):
             self.fh._read_header(mock.MagicMock())
-
-
-def suite():
-    """Test suite for test_scene."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestAHIHSDNavigation))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestAHIHSDFileHandler))
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
