@@ -15,18 +15,15 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
-"""Module for testing the satpy.readers.nucaps module.
-"""
+"""Module for testing the satpy.readers.nucaps module."""
 
 import os
-import sys
+import unittest
+from unittest import mock
 import numpy as np
 from satpy.tests.reader_tests.test_netcdf_utils import FakeNetCDF4FileHandler
 from satpy.tests.utils import convert_file_content_to_data_array
 
-import unittest
-from unittest import mock
-
 
 DEFAULT_FILE_DTYPE = np.float32
 DEFAULT_FILE_SHAPE = (120,)
@@ -513,14 +510,3 @@ class TestNUCAPSScienceEDRReader(unittest.TestCase):
                               (DEFAULT_PRES_FILE_SHAPE[0], 1))
         pl_ds = datasets['Pressure_Levels']
         self.assertTupleEqual(pl_ds.shape, (1,))
-
-
-def suite():
-    """The test suite for test_nucaps.
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestNUCAPSReader))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestNUCAPSScienceEDRReader))
-
-    return mysuite
