@@ -16,32 +16,23 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # Satpy.  If not, see <http://www.gnu.org/licenses/>.
-
-"""Module for testing the satpy.readers.tropomi_l2 module.
-"""
+"""Module for testing the satpy.readers.tropomi_l2 module."""
 
 import os
-import sys
+import unittest
+from unittest import mock
 from datetime import datetime
 import numpy as np
 from satpy.tests.reader_tests.test_netcdf_utils import FakeNetCDF4FileHandler
 import xarray as xr
 
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
 
 DEFAULT_FILE_DTYPE = np.uint16
 DEFAULT_FILE_SHAPE = (3246, 450)
 DEFAULT_FILE_DATA = np.arange(DEFAULT_FILE_SHAPE[0] * DEFAULT_FILE_SHAPE[1],
                               dtype=DEFAULT_FILE_DTYPE).reshape(DEFAULT_FILE_SHAPE)
+DEFAULT_BOUND_DATA = np.arange(DEFAULT_FILE_SHAPE[0] * DEFAULT_FILE_SHAPE[1] * 4,
+                               dtype=DEFAULT_FILE_DTYPE).reshape(DEFAULT_FILE_SHAPE+(4,))
 
 
 class FakeNetCDF4FileHandlerTL2(FakeNetCDF4FileHandler):
@@ -62,6 +53,8 @@ class FakeNetCDF4FileHandlerTL2(FakeNetCDF4FileHandler):
 
             file_content['PRODUCT/latitude'] = DEFAULT_FILE_DATA
             file_content['PRODUCT/longitude'] = DEFAULT_FILE_DATA
+            file_content['PRODUCT/SUPPORT_DATA/GEOLOCATIONS/latitude_bounds'] = DEFAULT_BOUND_DATA
+            file_content['PRODUCT/SUPPORT_DATA/GEOLOCATIONS/longitude_bounds'] = DEFAULT_BOUND_DATA
 
             if 'NO2' in filename:
                 file_content['PRODUCT/nitrogen_dioxide_total_column'] = DEFAULT_FILE_DATA
@@ -76,12 +69,16 @@ class FakeNetCDF4FileHandlerTL2(FakeNetCDF4FileHandler):
             # convert to xarrays
             for key, val in file_content.items():
                 if isinstance(val, np.ndarray):
-                    if val.ndim > 1:
+                    if 1 < val.ndim <= 2:
                         file_content[key] = DataArray(val, dims=('scanline', 'ground_pixel'))
+                    elif val.ndim > 2:
+                        file_content[key] = DataArray(val, dims=('scanline', 'ground_pixel', 'corner'))
                     else:
                         file_content[key] = DataArray(val)
             file_content['PRODUCT/latitude'].attrs['_FillValue'] = -999.0
             file_content['PRODUCT/longitude'].attrs['_FillValue'] = -999.0
+            file_content['PRODUCT/SUPPORT_DATA/GEOLOCATIONS/latitude_bounds'].attrs['_FillValue'] = -999.0
+            file_content['PRODUCT/SUPPORT_DATA/GEOLOCATIONS/longitude_bounds'].attrs['_FillValue'] = -999.0
             if 'NO2' in filename:
                 file_content['PRODUCT/nitrogen_dioxide_total_column'].attrs['_FillValue'] = -999.0
             if 'SO2' in filename:
@@ -160,16 +157,38 @@ class TestTROPOMIL2Reader(unittest.TestCase):
             self.assertIn('y', d.dims)
             self.assertIn('x', d.dims)
 
-
-def suite():
-    """The test suite for test_tropomi_l2.
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestTROPOMIL2Reader))
-
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
+    def test_load_bounds(self):
+        """Load bounds dataset"""
+        from satpy.readers import load_reader
+        r = load_reader(self.reader_configs)
+        with mock.patch('satpy.readers.tropomi_l2.netCDF4.Variable', xr.DataArray):
+            loadables = r.select_files_from_pathnames([
+                'S5P_OFFL_L2__NO2____20180709T170334_20180709T184504_03821_01_010002_20180715T184729.nc',
+            ])
+            r.create_filehandlers(loadables)
+        keys = ['latitude_bounds', 'longitude_bounds']
+        ds = r.load(keys)
+        self.assertEqual(len(ds), 2)
+        for key in keys:
+            self.assertEqual(ds[key].attrs['platform_shortname'], 'S5P')
+            self.assertIn('y', ds[key].dims)
+            self.assertIn('x', ds[key].dims)
+            self.assertIn('corner', ds[key].dims)
+            # check assembled bounds
+            left = np.vstack([ds[key][:, :, 0], ds[key][-1:, :, 3]])
+            right = np.vstack([ds[key][:, -1:, 1], ds[key][-1:, -1:, 2]])
+            dest = np.hstack([left, right])
+            dest = xr.DataArray(dest,
+                                dims=('y', 'x')
+                                )
+            dest.attrs = ds[key].attrs
+            self.assertEqual(dest.attrs['platform_shortname'], 'S5P')
+            self.assertIn('y', dest.dims)
+            self.assertIn('x', dest.dims)
+            self.assertEqual(DEFAULT_FILE_SHAPE[0] + 1, dest.shape[0])
+            self.assertEqual(DEFAULT_FILE_SHAPE[1] + 1, dest.shape[1])
+            self.assertIsNone(np.testing.assert_array_equal(dest[:-1, :-1], ds[key][:, :, 0]))
+            self.assertIsNone(np.testing.assert_array_equal(dest[-1, :-1], ds[key][-1, :, 3]))
+            self.assertIsNone(np.testing.assert_array_equal(dest[:, -1],
+                              np.append(ds[key][:, -1, 1], ds[key][-1:, -1:, 2]))
+                              )
