@@ -17,14 +17,8 @@
 # satpy.  If not, see <http://www.gnu.org/licenses/>.
 """Testing of helper functions."""
 
-
 import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
-
+from unittest import mock
 import os
 import sys
 import numpy as np
@@ -79,11 +73,15 @@ class TestHelpers(unittest.TestCase):
     def test_get_geostationary_bbox(self):
         """Get the geostationary bbox."""
         geos_area = mock.MagicMock()
+        del geos_area.crs
         lon_0 = 0
-        geos_area.proj_dict = {'a': 6378169.00,
-                               'b': 6356583.80,
-                               'h': 35785831.00,
-                               'lon_0': lon_0}
+        geos_area.proj_dict = {
+            'proj': 'geos',
+            'lon_0': lon_0,
+            'a': 6378169.00,
+            'b': 6356583.80,
+            'h': 35785831.00,
+            'units': 'm'}
         geos_area.area_extent = [-5500000., -5500000., 5500000., 5500000.]
 
         lon, lat = hf.get_geostationary_bounding_box(geos_area, 20)
@@ -107,20 +105,36 @@ class TestHelpers(unittest.TestCase):
     def test_get_geostationary_angle_extent(self):
         """Get max geostationary angles."""
         geos_area = mock.MagicMock()
-        geos_area.proj_dict = {'a': 6378169.00,
-                               'b': 6356583.80,
-                               'h': 35785831.00}
+        del geos_area.crs
+        geos_area.proj_dict = {
+            'proj': 'geos',
+            'sweep': 'x',
+            'lon_0': -89.5,
+            'a': 6378169.00,
+            'b': 6356583.80,
+            'h': 35785831.00,
+            'units': 'm'}
 
         expected = (0.15185342867090912, 0.15133555510297725)
-
         np.testing.assert_allclose(expected,
                                    hf.get_geostationary_angle_extent(geos_area))
 
-        geos_area.proj_dict = {'a': 1000.0,
-                               'b': 1000.0,
-                               'h': np.sqrt(2) * 1000.0 - 1000.0}
+        geos_area.proj_dict['a'] = 1000.0
+        geos_area.proj_dict['b'] = 1000.0
+        geos_area.proj_dict['h'] = np.sqrt(2) * 1000.0 - 1000.0
 
         expected = (np.deg2rad(45), np.deg2rad(45))
+        np.testing.assert_allclose(expected,
+                                   hf.get_geostationary_angle_extent(geos_area))
+
+        geos_area.proj_dict = {
+            'proj': 'geos',
+            'sweep': 'x',
+            'lon_0': -89.5,
+            'ellps': 'GRS80',
+            'h': 35785831.00,
+            'units': 'm'}
+        expected = (0.15185277703584374, 0.15133971368991794)
 
         np.testing.assert_allclose(expected,
                                    hf.get_geostationary_angle_extent(geos_area))
@@ -274,29 +288,15 @@ class TestHelpers(unittest.TestCase):
             self.assertTrue(os.path.exists(new_fname))
             if os.path.exists(new_fname):
                 os.remove(new_fname)
-        # bz2 installed, but python 3 only
-        if sys.version_info.major >= 3:
-            with mock.patch(whichstr) as whichmock:
-                whichmock.return_value = '/usr/bin/pbzip2'
-                new_fname = hf.unzip_file(filename)
-                self.assertTrue(mock_popen.called)
-                self.assertTrue(os.path.exists(new_fname))
-                if os.path.exists(new_fname):
-                    os.remove(new_fname)
+        # bz2 installed
+        with mock.patch(whichstr) as whichmock:
+            whichmock.return_value = '/usr/bin/pbzip2'
+            new_fname = hf.unzip_file(filename)
+            self.assertTrue(mock_popen.called)
+            self.assertTrue(os.path.exists(new_fname))
+            if os.path.exists(new_fname):
+                os.remove(new_fname)
 
         filename = 'tester.DAT'
         new_fname = hf.unzip_file(filename)
         self.assertIsNone(new_fname)
-
-
-def suite():
-    """Test suite for utils library."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestHelpers))
-
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
