@@ -113,6 +113,12 @@ from pyresample.geometry import AreaDefinition, SwathDefinition
 from satpy.writers import Writer
 from satpy.writers.utils import flatten_dict
 
+from distutils.version import LooseVersion
+import pyproj
+if LooseVersion(pyproj.__version__) < LooseVersion('2.4.1'):
+    # technically 2.2, but important bug fixes in 2.4.1
+    raise ImportError("'cf' writer requires pyproj 2.4.1 or greater")
+
 
 logger = logging.getLogger(__name__)
 
@@ -139,90 +145,12 @@ CF_DTYPES = [np.dtype('int8'),
 CF_VERSION = 'CF-1.7'
 
 
-def tmerc2cf(area):
-    """Return the cf grid mapping for the tmerc projection."""
-    proj_dict = area.proj_dict
-    args = dict(latitude_of_projection_origin=proj_dict.get('lat_0'),
-                longitude_of_central_meridian=proj_dict.get('lon_0'),
-                grid_mapping_name='transverse_mercator',
-                reference_ellipsoid_name=proj_dict.get('ellps', 'WGS84'),
-                false_easting=0.,
-                false_northing=0.
-                )
-    if "no_rot" in proj_dict:
-        args['no_rotation'] = 1
-    if "gamma" in proj_dict:
-        args['gamma'] = proj_dict['gamma']
-    return args
-
-
-def omerc2cf(area):
-    """Return the cf grid mapping for the omerc projection."""
-    proj_dict = area.proj_dict
-
-    args = dict(azimuth_of_central_line=proj_dict.get('alpha'),
-                latitude_of_projection_origin=proj_dict.get('lat_0'),
-                longitude_of_projection_origin=proj_dict.get('lonc'),
-                grid_mapping_name='oblique_mercator',
-                reference_ellipsoid_name=proj_dict.get('ellps', 'WGS84'),
-                prime_meridian_name=proj_dict.get('pm', 'Greenwich'),
-                horizontal_datum_name=proj_dict.get('datum', 'unknown'),
-                geographic_crs_name='unknown',
-                false_easting=0.,
-                false_northing=0.
-                )
-    if "no_rot" in proj_dict:
-        args['no_rotation'] = 1
-    if "gamma" in proj_dict:
-        args['gamma'] = proj_dict['gamma']
-    return args
-
-
-def geos2cf(area):
-    """Return the cf grid mapping for the geos projection."""
-    from pyresample.utils import proj4_radius_parameters
-    proj_dict = area.proj_dict
-    a, b = proj4_radius_parameters(proj_dict)
-    args = dict(perspective_point_height=proj_dict.get('h'),
-                latitude_of_projection_origin=proj_dict.get('lat_0', 0),
-                longitude_of_projection_origin=proj_dict.get('lon_0', 0),
-                grid_mapping_name='geostationary',
-                semi_major_axis=a,
-                semi_minor_axis=b,
-                # semi_major_axis=proj_dict.get('a'),
-                # semi_minor_axis=proj_dict.get('b'),
-                sweep_axis=proj_dict.get('sweep'),
-                )
-    return args
-
-
-def laea2cf(area):
-    """Return the cf grid mapping for the laea projection."""
-    proj_dict = area.proj_dict
-    args = dict(latitude_of_projection_origin=proj_dict.get('lat_0'),
-                longitude_of_projection_origin=proj_dict.get('lon_0'),
-                grid_mapping_name='lambert_azimuthal_equal_area',
-                )
-    return args
-
-
-mappings = {'omerc': omerc2cf,
-            'laea': laea2cf,
-            'geos': geos2cf,
-            'tmerc': tmerc2cf}
-
-
 def create_grid_mapping(area):
     """Create the grid mapping instance for `area`."""
-    try:
-        grid_mapping = mappings[area.proj_dict['proj']](area)
-        grid_mapping['name'] = area.proj_dict['proj']
-    except KeyError:
-        warnings.warn('The projection "{}" is either not CF compliant or not implemented yet. '
-                      'Using the proj4 string instead.'.format(area.proj_str))
-        grid_mapping = {'name': 'proj4', 'proj4': area.proj_str}
-
-    return grid_mapping
+    # let pyproj do the heavily lifting
+    # pyproj 2.0+ required
+    grid_mapping = area.crs.to_cf()
+    return area.area_id, grid_mapping
 
 
 def get_extra_ds(dataset):
@@ -237,8 +165,10 @@ def get_extra_ds(dataset):
 
 def area2lonlat(dataarray):
     """Convert an area to longitudes and latitudes."""
+    dataarray = dataarray.copy()
     area = dataarray.attrs['area']
-    lons, lats = area.get_lonlats_dask()
+    chunks = getattr(dataarray.data, 'chunks', None)
+    lons, lats = area.get_lonlats(chunks=chunks)
     lons = xr.DataArray(lons, dims=['y', 'x'],
                         attrs={'name': "longitude",
                                'standard_name': "longitude",
@@ -251,33 +181,26 @@ def area2lonlat(dataarray):
                         name='latitude')
     dataarray['longitude'] = lons
     dataarray['latitude'] = lats
-    return [dataarray]
+    return dataarray
 
 
 def area2gridmapping(dataarray):
     """Convert an area to at CF grid mapping."""
+    dataarray = dataarray.copy()
     area = dataarray.attrs['area']
-    attrs = create_grid_mapping(area)
-    if attrs is not None and 'name' in attrs.keys() and attrs['name'] != "proj4":
-        dataarray.attrs['grid_mapping'] = attrs['name']
-        name = attrs['name']
-    else:
-        # Handle the case when the projection cannot be converted to a standard CF representation or this has not
-        # been implemented yet.
-        dataarray.attrs['grid_proj4'] = area.proj4_string
-        name = "proj4"
-    return [dataarray, xr.DataArray(0, attrs=attrs, name=name)]
+    gmapping_var_name, attrs = create_grid_mapping(area)
+    dataarray.attrs['grid_mapping'] = gmapping_var_name
+    return dataarray, xr.DataArray(0, attrs=attrs, name=gmapping_var_name)
 
 
 def area2cf(dataarray, strict=False):
     """Convert an area to at CF grid mapping or lon and lats."""
     res = []
-    dataarray = dataarray.copy(deep=True)
     if isinstance(dataarray.attrs['area'], SwathDefinition) or strict:
-        res = area2lonlat(dataarray)
+        dataarray = area2lonlat(dataarray)
     if isinstance(dataarray.attrs['area'], AreaDefinition):
-        res.extend(area2gridmapping(dataarray))
-
+        dataarray, gmapping = area2gridmapping(dataarray)
+        res.append(gmapping)
     res.append(dataarray)
     return res
 
@@ -467,6 +390,7 @@ def encode_attrs_nc(attrs):
             Attributes to be encoded
     Returns:
         dict: Encoded (and sorted) attributes
+
     """
     encoded_attrs = []
     for key, val in sorted(attrs.items()):
@@ -491,11 +415,15 @@ class CFWriter(Writer):
                 If True, flatten dict-type attributes
             exclude_attrs (list):
                 List of dataset attributes to be excluded
+
         """
         if exclude_attrs is None:
             exclude_attrs = []
 
         new_data = dataarray.copy()
+        if 'name' in new_data.attrs:
+            name = new_data.attrs.pop('name')
+            new_data = new_data.rename(name)
 
         # Remove area as well as user-defined attributes
         for key in ['area'] + exclude_attrs:
@@ -534,7 +462,8 @@ class CFWriter(Writer):
         if 'crs' in new_data.coords:
             new_data = new_data.drop('crs')
 
-        new_data.attrs.setdefault('long_name', new_data.attrs.pop('name'))
+        if 'long_name' not in new_data.attrs and 'standard_name' not in new_data.attrs:
+            new_data.attrs['long_name'] = new_data.name
         if 'prerequisites' in new_data.attrs:
             new_data.attrs['prerequisites'] = [np.string_(str(prereq)) for prereq in new_data.attrs['prerequisites']]
 
@@ -561,18 +490,23 @@ class CFWriter(Writer):
         datas = {}
         start_times = []
         end_times = []
-        for ds_name, ds in sorted(ds_collection.items()):
+        # sort by name, but don't use the name
+        for _, ds in sorted(ds_collection.items()):
             if ds.dtype not in CF_DTYPES:
                 warnings.warn('Dtype {} not compatible with {}.'.format(str(ds.dtype), CF_VERSION))
+            # we may be adding attributes, coordinates, or modifying the
+            # structure of attributes
+            ds = ds.copy(deep=True)
             try:
                 new_datasets = area2cf(ds, strict=include_lonlats)
             except KeyError:
-                new_datasets = [ds.copy(deep=True)]
+                new_datasets = [ds]
             for new_ds in new_datasets:
                 start_times.append(new_ds.attrs.get("start_time", None))
                 end_times.append(new_ds.attrs.get("end_time", None))
-                datas[new_ds.attrs['name']] = self.da2cf(new_ds, epoch=epoch, flatten_attrs=flatten_attrs,
-                                                         exclude_attrs=exclude_attrs, compression=compression)
+                new_var = self.da2cf(new_ds, epoch=epoch, flatten_attrs=flatten_attrs,
+                                     exclude_attrs=exclude_attrs, compression=compression)
+                datas[new_var.name] = new_var
 
         # Check and prepare coordinates
         assert_xy_unique(datas)
@@ -589,7 +523,7 @@ class CFWriter(Writer):
         other_to_netcdf_kwargs = to_netcdf_kwargs.copy()
         encoding = other_to_netcdf_kwargs.pop('encoding', {}).copy()
         coord_vars = []
-        for name, data_array in dataset.items():
+        for data_array in dataset.values():
             coord_vars.extend(set(data_array.dims).intersection(data_array.coords))
         for coord_var in coord_vars:
             encoding.setdefault(coord_var, {})
@@ -650,6 +584,7 @@ class CFWriter(Writer):
                 Compression to use on the datasets before saving, for example {'zlib': True, 'complevel': 9}.
                 This is in turn passed the xarray's `to_netcdf` method:
                 http://xarray.pydata.org/en/stable/generated/xarray.Dataset.to_netcdf.html for more possibilities.
+
         """
         logger.info('Saving datasets to NetCDF4/CF.')
 
